filegardener
============
File gardener - file maintenance utilities - file dedup, only copy detection, prune empty dirs


.. image:: https://img.shields.io/smorin/v/filegardener.svg
   :target: https://pypi.python.org/smorin/filegarderner

.. image:: https://img.shields.io/travis/smorin/filegardener/master.svg
   :target: http://travis-ci.org/smorin/filegardener

.. image:: https://readthedocs.org/projects/filegardener/badge/?version=stable
   :target: https://readthedocs/en/stable


* `Github Page <https://github.com/smorin/filegardener>`_
* `Issue Tracking <https://github.com/smorin/filegardener/issues>`_


